@@ -48,6 +48,8 @@ zypper in -y MozillaThunderbird MozillaThunderbird-translations-common
 # addrepo.sh adds special repo for that 
 zypper in -y google-chrome-stable mathjax
 
+zypper in -y gstreamer-plugin-openh264 mozilla-openh264
+
 # `okular` and `okular-lang` are installed in basic version but needed are also
 # calligra to allow odp,... and spectre for forms 
 # `evince` for support of xfa forms. 
@@ -118,6 +120,7 @@ zypper in -y \
     `# Photini, exiv2 and gexif along the same lines as exif` \
   unoconv pandoc texinfo libreoffice `# converter; texinfo implies texihtml and texiroff` \
   xfig gnuplot inkscape `# converter` \
+  libwebp-tools `# converter from webp to png, not yet used` \
   docbook2x discount `# the latter providing command 'markdown'` \
   rubber `# make utils texlive-arara? latexmake not present` \
   epstool `# eps files in latex also for octave` \
@@ -172,7 +175,8 @@ zypper in -y java-11-openjdk-src java-11-openjdk java-11-openjdk-devel `# java11
 	java-17-openjdk-src java-17-openjdk java-17-openjdk-devel `#j ava17 needed for redhead plugin` \
   java-1_8_0-openjdk-src java-1_8_0-openjdk java-1_8_0-openjdk-devel `# java1.8 for latex plugin` \
   `#openjfx # also for jabref` \
-  maven `# basic build tool`
+  maven `# basic build tool` \
+  jenkins dejavu-fonts fontconfig 
 
 
 # some utilities 
@@ -180,13 +184,15 @@ zypper in -y kruler cheese `# webcam` \
   system-user-uucp uucp cutecom moreutils zip bzip2-doc gparted \
   dhex ktorrent stress-ng \
   sensors acpi hddtemp hardinfo qt6-sensors `# temperature monitoring` \
+  lshw `# hardware info` \
   xsane spectacle gimp k3b `# scanning, screenshot, image processing and burning` \
   vlc `# films` \
   whatsapp-purple `# displaylink not found` \
   `# the proper app: not working whatsie.x86_64 could be whatsapp-for-linux` \
   `# skype whatsapp is with snap currently, maybe skypeforlinux or flatpak` \
   kdeconnect-kde `# of course also on mobile kdeconnect must be installed. ` \
-  dropbox-cli `# a drop box comand line client `
+  dropbox-cli `# a drop box comand line client ` \
+  luvcview `# driver for most webcams`
 
 
 # there are much more packages on octave-forge worth being investigated
@@ -227,6 +233,9 @@ systemctl enable docker
 zypper in -y podman podmansh #podman-docker
 
 
+zypper in -y inotify-tools
+
+
 zypper in -y distrobox distrobox-bash-completion
 # This was a trial on tikzit 
 # more general, distrobox is very useful to invite other linux distributions 
